const webpack = require('webpack')
const path = require('path')
const merge = require('webpack-merge')
const nodeExternals = require('webpack-node-externals')
const VueSSRServerPlugin = require('vue-server-renderer/server-plugin')
const { projectPath } = require('../utils')
const { IS_PROD } = require('./env.config')
const appConfig = require('../utils/get-app-config')

const baseConfig = require('./webpack.base.config')

const publicPath = appConfig.deploy && appConfig.deploy.project || 'public'

module.exports = merge(baseConfig, {
  module: {
    rules: [
      {
        test: /\.js$/,
        use: 'babel-loader',
        include: [resolve('client'), resolve('test')],
        enforce: 'post',
        use: [{
          loader: 'istanbul-instrumenter-loader',
          options: {
            esModules: true
          },
        }],
      },
      {
        test: /\.vue$/,
        use: [{
          loader: 'vue-loader',
          options: {
            // 为了统计代码覆盖率，对 vue 文件加入 istanbul-instrumenter-loader
            preLoaders: {
              js: 'istanbul-instrumenter-loader?esModules=true'
            }
          }
        }]
      },
    ]
  },
  plugins: [
    new webpack.DefinePlugin({
      'process.env': {
        NODE_ENV: '"test"'
      }
    })
  ],
})
